@@ -27,7 +27,7 @@ import jinjafx, os, io, socket, signal, threading, yaml, json, base64, time, dat
 import re, argparse, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests, ctypes, subprocess
 import cmarkgfm, emoji
 
-__version__ = '25.7.7'
+__version__ = '25.7.11'
 
 llock = threading.RLock()
 rlock = threading.RLock()
@@ -619,11 +619,11 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
 
             except TemplateError as e:
               if hasattr(e, 'name') and e.name and hasattr(e, 'lineno') and e.lineno:
-                t = e.name.replace('Default', 'template.j2')
-                error = f'error[{t}:{e.lineno}]: {type(e).__name__}: {e}'
+                error = f'error[{e.name}:{e.lineno}]: {type(e).__name__}: {e}'
 
               else:
                 error = jinjafx._format_error(e, 'template code')
+                error = error.replace('__init__.py:', 'jinjafx_server.py:')
 
               jsr = {
                 'status': 'error',
@@ -633,6 +633,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
 
             except Exception as e:
               error = jinjafx._format_error(e, 'template code', '_jinjafx')
+              error = error.replace('__init__.py:', 'jinjafx_server.py:')
 
               jsr = {
                 'status': 'error',
@@ -652,7 +653,7 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 try:
                   if not self.ratelimit(remote_addr, 4, False):
                     html = self.d(json.loads(postdata.decode('utf-8')))
-                    p = subprocess.run([pandoc, '-f', 'html', '-t', 'docx', '--sandbox', '--standalone', '--embed-resources', '--reference-doc=' + base + '/pandoc/reference.docx'], input=html, stdout=subprocess.PIPE, check=True)
+                    p = subprocess.run([pandoc, '-f', 'html', '-t', 'docx', '-o', '-', '--sandbox', '--standalone', '--embed-resources', '--reference-doc=' + base + '/pandoc/reference.docx'], input=html, stdout=subprocess.PIPE, check=True)
                     self.send_response(200)
                     self.send_header('Content-Type', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document')
                     self.send_header('Content-Length', str(len(p.stdout)))
@@ -1241,9 +1242,8 @@ def main(rflag=[0]):
 
 
   except Exception as e:
-    exc_type, exc_obj, exc_tb = sys.exc_info()
-    fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
-    print('error[jinjafx_server.py:' + str(exc_tb.tb_lineno) + ']: ' + str(e), file=sys.stderr)
+    error = jinjafx._format_error(e)
+    print(error.replace('__init__.py:', 'jinjafx_server.py:'), file=sys.stderr)
     sys.exit(-2)
 
   finally:
